# শুরু হও!

Python এবং R এর জন্য আধুনিক ডেভেলপমেন্ট পরিবেশ Rapunzel-এ স্বাগতম। এখানে কিছু হাতের মূলে কিবোর্ড শর্টকাট রয়েছে।

## প্রকল্পের ফোল্ডার এবং ফাইলগুলির সাথে কাজ করা

- [`Ctrl+Shift+O`: প্রকল্পের ফোল্ডারটি খুলুন](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: প্রকল্পের ফোল্ডার থেকে ফাইল খুলুন](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: খালি নথি তৈরি করা](opensesame://event.ide_new_file)

## দ্রুত কাজ করা

- [`Ctrl+Shift+P`: কমান্ড প্যালেট চালু করা](opensesame://event.command_palette_activate)
- `Ctrl+R`: ফাংশন বা ক্লাসে যাও

## কোড চালান

- `F5`: প্রকল্প বা ফাইল চালান
- `F9`: নির্বাচন, সেল বা বর্তমান লাইন চালান